OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendariu",
    "Individual" : "Individual",
    "Group" : "Grupu",
    "Resource" : "Recursu",
    "Room" : "Habitación",
    "Unknown" : "Desconocí­u",
    "Required" : "Riquíu",
    "Optional" : "Opcional",
    "Does not attend" : "Nun atiendi",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Tas nunca zona horaria desconocia  ({tz}), torna a UTC",
    "Please create a calendar first." : "Por favor, crea entantes un calendariu.",
    "New event" : "Nuevu eventu",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repetición",
    "When shared show full event" : "Amosar l'eventu completu al compartir",
    "When shared show only busy" : "Amosar namás ocupáu al compartir",
    "When shared hide this event" : "Anubrir l'eventu al compartir",
    "Confirmed" : "Confirmáu",
    "Tentative" : "Tentativa",
    "Cancelled" : "Encaboxáu",
    "Please add a title!" : "¡Por favor, amiesta un títulu!",
    "Please select a calendar!" : "¡Por favor, esbilla un calendariu!",
    "Global" : "Global",
    "None" : "Dengún",
    "Every day" : "Acaldía",
    "Every week" : "Cada selmana",
    "Every month" : "Cada mes",
    "Every year" : "Cada añu",
    "never" : "enxamás",
    "after" : "dempués",
    "At time of event" : "A la hora l'eventu",
    "5 minutes before" : "5 minutos enantes",
    "10 minutes before" : "10 minutos enantes",
    "15 minutes before" : "15 minutos enantes",
    "30 minutes before" : "30 minutos enantes",
    "1 hour before" : "1 hora enantes",
    "2 hours before" : "2 hores enantes",
    "Custom" : "Personalizáu",
    "Audio" : "Audiu",
    "E Mail" : "Corréu",
    "Pop up" : "Ventanu emerxente",
    "sec" : "seg",
    "min" : "mín.",
    "hours" : "hores",
    "days" : "díes",
    "week" : "selmana",
    "before" : "enantes",
    "start" : "entamu",
    "end" : "fin",
    "Editing reminders of unknown type not supported." : "Nun ta soportáu l'editar recordatorios de triba desconocida",
    "Week {number} of {year}" : "Selmana {number} del {year}",
    "Successfully imported" : "Importáu ensin fallos",
    "Partially imported, 1 failure" : "Importáu parcialmente, 1 fallu",
    "Partially imported, {n} failures" : "Importáu parcialmente, {n} fallos",
    "Audio alarm" : "Alarma d'audiu",
    "Pop-up" : "Ventanu emerxente",
    "E-Mail" : "Corréu",
    "{type} {time} before the event starts" : "{type} {time} enantes que l'enventu entame",
    "{type} {time} before the event ends" : "{type} {time} enantes que l'eventu fine",
    "{type} {time} after the event starts" : "{type} {time} dempués que l'eventu entame",
    "{type} {time} after the event ends" : "{type} {time} dempués que l'eventu fine",
    "{type} at the event's start" : "{type} al entamu l'eventu",
    "{type} at the event's end" : "{type} cuando l'enventu fine",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartíu por  {owner}",
    "Title of the Event" : "Títulu del eventu",
    "starts" : "entama",
    "ends" : "fina",
    "All day Event" : "Tol día",
    "Delete" : "Desaniciar",
    "Cancel" : "Encaboxar",
    "More ..." : "Más ...",
    "Create" : "Crear",
    "Update" : "Anovar",
    "Close" : "Zarrar",
    "Location" : "Llocalización",
    "Description" : "Descripción",
    "Event status" : "Estáu del eventu",
    "Visibility when sharing" : "Visibilida mientres compartes",
    "Export" : "Esportar",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Por cuenta d'un bug d'upstream, el calendariu nun soporta la carauterística d'asset pipeline",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contauta col to alministrador y pídi-y que desactive la opción de configuración \"asset-pipeline.enabled\".",
    "Day" : "Día",
    "Week" : "Selmana",
    "Month" : "Mes",
    "Today" : "Güei",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Dalgunos eventos nesti calendariu tán francíos. Por favor, compruebe la consola JS pa más información.",
    "Share Calendar" : "Compartir calendariu",
    "Shared" : "Compartíu",
    "More" : "Más",
    "Edit" : "Editar",
    "Link" : "Enllaz",
    "Download" : "Baxar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "can edit" : "pue editar",
    "group" : "grupu",
    "New Calendar" : "Calendariu nuevu",
    "Subscriptions" : "Soscripciones ",
    "New Subscription" : "Nueva Soscripción",
    "Url" : "Url",
    "Edit event" : "Editar eventu",
    "Delete Event" : "Desaniciar Eventu",
    "Save Event" : "Guardar Eventu",
    "Time" : "Hora",
    "Type" : "Triba",
    "Relative" : "Relativu",
    "Absolute" : "Absolutu",
    "Repeat" : "Repitir",
    "times every" : "cada vegada",
    "Add" : "Amestar",
    "E-Mail address of attendee" : "Direición de corréu del asistente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor amiesta'l to corréu nos axustes de la so cuenta p'amestar asistentes",
    "from" : "Dende",
    "to" : "hasta",
    "This event's repeating rule is not supported yet." : "Esta riegla de repetición d'eventos entá nun ta soportada.",
    "Support for advanced rules will be added with subsequent updates." : "Soporte pa riegles avanzaes va amestase con actualizaciones posteriores.",
    "Reset repeating rule" : "Reafitar repetición de regla",
    "Repeat every ..." : "Repitir acaldía ...",
    "end repeat ..." : "finar repetición ...",
    "times" : "vegaes",
    "Import Calendars" : "Importar Calendarios",
    "Import canceled" : "Desaniciar importación",
    "Analyzing calendar" : "Analizando calendariu",
    "The file contains objects incompatible with the selected calendar" : "El ficheru contién oxetos incompatibles col calendariu esbilláu",
    "New calendar" : "Calendariu nuevu",
    "Import scheduled" : "Importar horariu",
    "Settings" : "Axustes",
    "Skip simple event editor" : "Saltar editor d'eventos simples",
    "Import calendar" : "Importar calendariu",
    "No Calendars selected for import" : "Nun s'esbilló nengún calendariu pa la importación",
    "Primary CalDAV address" : "Direición de calendariu CalDAV primariu",
    "iOS/OS X CalDAV address" : "Direición de calendariu CalDAV iOS/OSX"
},
"nplurals=2; plural=(n != 1);");
